==> vala-0.0.9.tar.gz: vala-0.0.9/vala/valalambdaexpression.h <==
/* valalambdaexpression.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALALAMBDAEXPRESSION_H__
#define __VALALAMBDAEXPRESSION_H__

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <vala/valaexpression.h>
#include <vala/valacodenode.h>

G_BEGIN_DECLS


#define VALA_TYPE_LAMBDA_EXPRESSION (vala_lambda_expression_get_type ())
#define VALA_LAMBDA_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LAMBDA_EXPRESSION, ValaLambdaExpression))
#define VALA_LAMBDA_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LAMBDA_EXPRESSION, ValaLambdaExpressionClass))
#define VALA_IS_LAMBDA_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LAMBDA_EXPRESSION))
#define VALA_IS_LAMBDA_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LAMBDA_EXPRESSION))
#define VALA_LAMBDA_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LAMBDA_EXPRESSION, ValaLambdaExpressionClass))

typedef struct _ValaLambdaExpressionPrivate ValaLambdaExpressionPrivate;

/**
 * Represents a lambda expression in the source code. Lambda expressions are
 * anonymous methods with implicitly typed parameters.
 */
struct _ValaLambdaExpression {
	ValaExpression parent;
	ValaLambdaExpressionPrivate * priv;
};
struct _ValaLambdaExpressionClass {
	ValaExpressionClass parent;
};

ValaLambdaExpression* vala_lambda_expression_new (ValaExpression* body, ValaSourceReference* source);
ValaLambdaExpression* vala_lambda_expression_new_with_statement_body (ValaBlock* body, ValaSourceReference* source);
void vala_lambda_expression_add_parameter (ValaLambdaExpression* self, const char* param);
GList* vala_lambda_expression_get_parameters (ValaLambdaExpression* self);
ValaExpression* vala_lambda_expression_get_expression_body (ValaLambdaExpression* self);
void vala_lambda_expression_set_expression_body (ValaLambdaExpression* self, ValaExpression* value);
ValaBlock* vala_lambda_expression_get_statement_body (ValaLambdaExpression* self);
void vala_lambda_expression_set_statement_body (ValaLambdaExpression* self, ValaBlock* value);
ValaMethod* vala_lambda_expression_get_method (ValaLambdaExpression* self);
void vala_lambda_expression_set_method (ValaLambdaExpression* self, ValaMethod* value);
GType vala_lambda_expression_get_type ();

G_END_DECLS

#endif

==> vala-0.5.3.tar.gz: vala-0.5.3/vala/valalambdaexpression.h <==
/* valalambdaexpression.vala
 *
 * Copyright (C) 2006-2008  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALA_VALALAMBDAEXPRESSION_H__
#define __VALA_VALALAMBDAEXPRESSION_H__

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gee/list.h>
#include <vala/valaexpression.h>
#include <vala/valacodenode.h>

G_BEGIN_DECLS


#define VALA_TYPE_LAMBDA_EXPRESSION (vala_lambda_expression_get_type ())
#define VALA_LAMBDA_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_LAMBDA_EXPRESSION, ValaLambdaExpression))
#define VALA_LAMBDA_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_LAMBDA_EXPRESSION, ValaLambdaExpressionClass))
#define VALA_IS_LAMBDA_EXPRESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_LAMBDA_EXPRESSION))
#define VALA_IS_LAMBDA_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_LAMBDA_EXPRESSION))
#define VALA_LAMBDA_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_LAMBDA_EXPRESSION, ValaLambdaExpressionClass))

typedef struct _ValaLambdaExpressionPrivate ValaLambdaExpressionPrivate;

/**
 * Represents a lambda expression in the source code. Lambda expressions are
 * anonymous methods with implicitly typed parameters.
 */
struct _ValaLambdaExpression {
	ValaExpression parent_instance;
	ValaLambdaExpressionPrivate * priv;
};

struct _ValaLambdaExpressionClass {
	ValaExpressionClass parent_class;
};


ValaLambdaExpression* vala_lambda_expression_construct (GType object_type, ValaExpression* expression_body, ValaSourceReference* source_reference);
ValaLambdaExpression* vala_lambda_expression_new (ValaExpression* expression_body, ValaSourceReference* source_reference);
ValaLambdaExpression* vala_lambda_expression_construct_with_statement_body (GType object_type, ValaBlock* statement_body, ValaSourceReference* source_reference);
ValaLambdaExpression* vala_lambda_expression_new_with_statement_body (ValaBlock* statement_body, ValaSourceReference* source_reference);
void vala_lambda_expression_add_parameter (ValaLambdaExpression* self, const char* param);
GeeList* vala_lambda_expression_get_parameters (ValaLambdaExpression* self);
ValaExpression* vala_lambda_expression_get_expression_body (ValaLambdaExpression* self);
void vala_lambda_expression_set_expression_body (ValaLambdaExpression* self, ValaExpression* value);
ValaBlock* vala_lambda_expression_get_statement_body (ValaLambdaExpression* self);
void vala_lambda_expression_set_statement_body (ValaLambdaExpression* self, ValaBlock* value);
ValaMethod* vala_lambda_expression_get_method (ValaLambdaExpression* self);
void vala_lambda_expression_set_method (ValaLambdaExpression* self, ValaMethod* value);
GType vala_lambda_expression_get_type (void);


G_END_DECLS

#endif
